#
# spec file for package gstreamer-editing-services
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2013 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name gst-editing-services

Name:           gstreamer-editing-services
Version:        1.24.10
Release:        1.1
Summary:        GStreamer Editing Services
License:        LGPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
URL:            https://gstreamer.freedesktop.org/data/doc/gstreamer/head/gstreamer-editing-services/html/ges-architecture.html
Source0:        https://gstreamer.freedesktop.org/src/gstreamer-editing-services/%{_name}-%{version}.tar.xz
Patch0:         gstreamer-editing-services-glib2.patch

BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  flex
BuildRequires:  meson >= 1.1
BuildRequires:  pkgconfig
BuildRequires:  python3-gobject-devel
BuildRequires:  pkgconfig(bash-completion) >= 2.0
BuildRequires:  pkgconfig(gio-2.0) >= 2.16
BuildRequires:  pkgconfig(glib-2.0) >= 2.40.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.9.6
BuildRequires:  pkgconfig(gstreamer-1.0) >= %{version}
BuildRequires:  pkgconfig(gstreamer-controller-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0) >= %{version}
BuildRequires:  pkgconfig(gstreamer-plugins-bad-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= %{version}
BuildRequires:  pkgconfig(gstreamer-validate-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 2.91.3
BuildRequires:  pkgconfig(gtk+-x11-3.0) >= 2.91.3
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(pygobject-3.0)

%description
The GStreamer multimedia framework and the accompanying GNonLin set
of plugins for non-linear editing offer all the building blocks
for:
Decoding and encoding to a wide variety of formats, through all the
available GStreamer plugins.
Easily choosing segments of streams and arranging them through time
through the GNonLin set of plugins.

But all those building blocks only offer stream-level access, which
results in developers who want to write non-linear editors to write
a consequent amount of code to get to the level of non-linear
editing notions which are closer and more meaningful for the
end-user (and therefore the application).

The GStreamer Editing Services (hereafter GES) aims to fill the gap
between GStreamer/GNonLin and the application developer by offering
a series of classes to simplify the creation of many kind of
editing-related applications.

%package -n libges-1_0-0
Summary:        GStreamer Editing Services - Libraries
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n libges-1_0-0
The GStreamer multimedia framework and the accompanying GNonLin set
of plugins for non-linear editing offer all the building blocks
for:
Decoding and encoding to a wide variety of formats, through all the
available GStreamer plugins.
Easily choosing segments of streams and arranging them through time
through the GNonLin set of plugins.

But all those building blocks only offer stream-level access, which
results in developers who want to write non-linear editors to write
a consequent amount of code to get to the level of non-linear
editing notions which are closer and more meaningful for the
end-user (and therefore the application).

The GStreamer Editing Services (hereafter GES) aims to fill the gap
between GStreamer/GNonLin and the application developer by offering
a series of classes to simplify the creation of many kind of
editing-related applications.

%package -n typelib-1_0-GES-1_0
Summary:        GStreamer Editing Services - Libraries
License:        GPL-3.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries

%description -n typelib-1_0-GES-1_0
The GStreamer multimedia framework and the accompanying GNonLin set
of plugins for non-linear editing offer all the building blocks
for:
Decoding and encoding to a wide variety of formats, through all the
available GStreamer plugins.
Easily choosing segments of streams and arranging them through time
through the GNonLin set of plugins.

But all those building blocks only offer stream-level access, which
results in developers who want to write non-linear editors to write
a consequent amount of code to get to the level of non-linear
editing notions which are closer and more meaningful for the
end-user (and therefore the application).

The GStreamer Editing Services (hereafter GES) aims to fill the gap
between GStreamer/GNonLin and the application developer by offering
a series of classes to simplify the creation of many kind of
editing-related applications.

%package devel
Summary:        GStreamer Editing Services - Development files
License:        GPL-3.0-or-later AND LGPL-2.1-or-later
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}
Requires:       libges-1_0-0 = %{version}
Requires:       typelib-1_0-GES-1_0 = %{version}

%description devel
The GStreamer multimedia framework and the accompanying GNonLin set
of plugins for non-linear editing offer all the building blocks
for:
Decoding and encoding to a wide variety of formats, through all the
available GStreamer plugins.
Easily choosing segments of streams and arranging them through time
through the GNonLin set of plugins.

But all those building blocks only offer stream-level access, which
results in developers who want to write non-linear editors to write
a consequent amount of code to get to the level of non-linear
editing notions which are closer and more meaningful for the
end-user (and therefore the application).

The GStreamer Editing Services (hereafter GES) aims to fill the gap
between GStreamer/GNonLin and the application developer by offering
a series of classes to simplify the creation of many kind of
editing-related applications.

%prep
%autosetup -p3 -n %{_name}-%{version}

%build
%meson \
	-Ddoc=disabled \
	-Dintrospection=enabled \
	-Dtests=disabled \
	%{nil}
%meson_build

%install
%meson_install

%ldconfig_scriptlets -n libges-1_0-0

%files
%license COPYING
%{_mandir}/man1/ges-launch-1.0.1%{?ext_man}
%{_bindir}/ges-launch-1.0
%{_datadir}/bash-completion/completions/ges-launch-1.0
%dir %{python_sitearch}/gi
%dir %{python_sitearch}/gi/overrides
%{python_sitearch}/gi/overrides/GES.py
%{python_sitearch}/gi/overrides/__pycache__/

%files -n libges-1_0-0
%license COPYING
%{_libdir}/gstreamer-1.0/libgstges.so
%{_libdir}/gstreamer-1.0/libgstnle.so
%{_libdir}/libges-1.0.so.*

%files -n typelib-1_0-GES-1_0
%{_libdir}/girepository-1.0/GES-1.0.typelib

%files devel
%doc ChangeLog README
%{_datadir}/gir-1.0/GES-1.0.gir
%{_includedir}/gstreamer-1.0/ges/
%{_libdir}/libges-1.0.so
%{_libdir}/pkgconfig/gst-editing-services-1.0.pc

%changelog
* Mon Dec  9 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.10:
  + No changes, stable version bump only.
* Tue Nov  5 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.9:
  + ges: Fix name of GESFrameCompositionMeta API type (which caused
    gobject-introspection failures at build time)
- Drop 7556.patch: Fixed upstream.
* Mon Sep 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.8:
  + discoverer-manager: Fix race leading to assertion when stopping
  + structured-interface: Fix memory leak of invalid fields GList
* Mon Sep 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add two upstream patches to fix build against GNOME 47
  infrastructure:
  + gstreamer-editing-services-glib2.patch: use g_sort_array()
    instead of deprecated g_qsort_with_data().
  + 7556.patch: ges: Fix name of GESFrameCompositionMeta API type.
- Apply patcheswith -p3: In upstream git, gstreamer is organized in
  one repository with subprojects, which are then shipped as
  tarballs each.
* Fri Aug 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.7:
  + nlecomposition: Don't leak QoS events.
* Wed Aug 14 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.6:
  + Highlighted bugfixes:
  - Fix compatibility with FFmpeg 7.0.
  - qmlglsink: Fix failure to display content on recent Android
    devices.
  - adaptivedemux: Fix handling of closed caption streams.
  - cuda: Fix runtime compiler loading with old CUDA tookit.
  - decodebin3 stream selection handling fixes.
  - d3d11compositor, d3d12compositor: Fix transparent background
    mode with YUV output.
  - d3d12converter: Make gamma remap work as intended.
  - h264decoder: Update output frame duration for interlaced
    video when second field frame is discarded.
  - macOS audio device provider now listens to audio devices
    being added/removed at runtime.
  - Rust plugins: audioloudnorm, s3hlssink, gtk4paintablesink,
    livesync and webrtcsink fixes.
  - videoaggregator: preserve features in non-alpha caps for
    subclasses with non-system memory sink caps.
  - vtenc: Fix redistribute latency spam.
  - v4l2: fixes for complex video formats.
  - va: Fix strides when importing DMABUFs, dmabuf handle leaks,
    and blocklist unmaintained Intel i965 driver for encoding.
  - waylandsink: Fix surface cropping for rotated streams.
  - webrtcdsp: Enable multi_channel processing to fix handling of
    stereo streams.
  - Various bug fixes, memory leak fixes, and other stability and
    reliability improvements.
* Fri Jun 28 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.5:
  + Highlighted bugfixes:
  - webrtcsink: Support for AV1 via nvav1enc, av1enc or rav1enc
    encoders
  - AV1 RTP payloader/depayloader fixes to work correctly with
    Chrome and Pion WebRTC
  - av1parse, av1dec error handling/robustness improvements
  - av1enc: Handle force-keyunit events properly for WebRTC
  - decodebin3: selection and collection handling improvements
  - hlsdemux2: Various fixes for discontinuities, variant
    switching, playlist updates
  - qml6glsink: fix RGB format support
  - rtspsrc: more control URL handling fixes
  - v4l2src: Interpret V4L2 report of sync loss as video signal
    loss
  - d3d12 encoder, memory and videosink fixes
  - vtdec: more robust error handling, fix regression
  - ndi: support for NDI SDK v6
  - Various bug fixes, memory leak fixes, and other stability and
    reliability improvements
- Please see https://gstreamer.freedesktop.org/releases/1.24/ for
  changes between 1.24.0 and this version and even more in-depth
  info.
* Tue Mar  5 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.24.0:
  * GStreamer Editing Services and NLE
  - Implement a gesvideoscale effect which gives user the ability
    to chooses where a clip has to be scaled in the chain of
    effects. By default scaling is done in the compositor.
  - Add support for gessrc as sub-timeline element so third party
    can implement their own formatters and use their timelines as
    sub-timelines. Before that, only timelines serialized as
    files on the filesystem could be loaded as sub-timelines
    (using gesdemux).
  - Implement a new GESDiscovererManager singleton object making
    management of the discoverers used to discoverer media files
    cleaner and allowing to expose the following APIs:
  * load-serialize-info signal so GstDiscovererInfo can be
    serialized by users the way they like and load them without
    requiring discovering the file when reloading a project.
  * source-setup signal so user can tweak source elements
    during discovery
  - Expose GESFrameCompositionMeta in public API so user can
    implement their own effects targetting GES which take into
    account that meta.
  - Expose audioconvert:mix-matrix property in audio sources
  - Port GESPipeline rendering to use encodebin2. This allows
    rendering timelines directly with a muxing sink (like
    hlssinkX etc..) and leverage all new features of that new
    element.
  * ges-launch
  - Fix setting keyframes
  - Add an ignore-eos option
  - Allow overriding container profile so that the user can build
    encoding profiles following the media format of a specific
    media file, for example, but ensuring it is muxed using a
    specific format
  - Ensure sink elements are inside a GstBin and never in a
    GstPipeline
  - Move +effect stack effects from source to last effect added,
    so it feels more natural to user as adding them at the
    beginning of the chain while the syntax is +effect felt wrong
  * For more detailed information on this update, please see
    https://gstreamer.freedesktop.org/releases/1.24/
- Remove patch reduce-required-meson.patch since meson 1.1 is
  really required now.
* Thu Feb  1 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.9:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Thu Jan  4 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.8:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Wed Nov 15 2023 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.7:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Fri Sep 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.6:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Tue Jul 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.5:
  + ges: some fixes for 32-bit systems
  + ges, nle: Avoid setting state or sending query when
    constructing objects
- Rebase reduce-required-meson.patch.
* Sat Jul 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Use ldconfig_scriptlets macro.
- Package pycache files now built and installed with new meson 1.2.
* Mon Jun 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.4:
  + ges: launcher: Never put sinks in a GstPipeline.
- Rebase reduce-required-meson.patch.
* Wed May 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.3:
  + ges: base-xml-formatter: Don't pass non-GObject pointers to
    GST_DEBUG_OBJECT.
- Rebase reduce-required-meson.patch.
* Wed Apr 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.2:
  + No changes, version bump only.
- Refresh patch.
* Thu Mar  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.1:
  + Fix gstreamer-validate-1.0 dependency name.
- Rebase patch with quilt.
- Drop gst-editing-services-fix-pc-name.patch: Fixed upstream.
* Wed Mar  1 2023 Antonio Larrosa <alarrosa@suse.com>
- Add patch to reduce the required meson version to 0.61.0 since
  that's what we have in SLE 15:
  * reduce-required-meson.patch
* Thu Jan 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.0:
  + Please see changes in gstreamer main package, major version
    bump.
- Add gst-editing-services-fix-pc-name.patch: pc file was renamed.
- Replace pkgconfig(gst-validate-1.0) with
  pkgconfig(gstreamer-validate-1.0) BuildRequires.
* Fri Dec 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.5:
  + Fix building ges with tools disabled
  + Fix leaks and minor races in GES
* Sat Oct 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.4:
  + Deadlock in ges because of recursive gst_init() call.
  + ges/gstframepositioner: don't create one compositor per frame
    meta.
  + nle: clear seek event properly.
* Wed Jun 22 2022 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 1.20.3:
  + Update validate test scenarios for videoaggregator rounding
    behaviour change
* Mon May  9 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.20.2:
  + License clarification: GES is released under the LGPL2+ license
* Fri Mar 18 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.20.1:
  + Update validate test scenarios for videoaggregator rounding
    behaviour change
* Wed Feb  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.0:
  + Framepositioner: new "operator" property to access blending
    modes in the compositor.
  + timeline: Implement snapping to markers.
  + smart-mixer: Add support for d3d11compositor and glvideomixer.
  + titleclip: add "draw-shadow" child property.
  + ges:// URI support to define a timeline from a description.
  + command-line-formatter:
  - Add track management to timeline description.
  - Add keyframe support.
  + ges-launch-1.0:
  - Add an interactive mode where we can seek etc...
  - Add option to forward tags
  - Allow using an existing clip to determine the rendering
    format (both topology and profile) via new --profile-from
    command line argument.
  + Fix static build.
* Fri Feb  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.6:
  + meson: Remove duplicate definition of 'examples' option
- Drop service, use source url, upstream changes in git.
* Thu Jan 20 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Fix parameters passed to meson: gtk_doc should be doc. Meson 0.60
  became strict and no longer accepts invalid parameters.
- Drop hotdoc BuildRequires: as we pass -Ddoc=disabled to meson,
  this dependency is not needed.
* Wed Sep 15 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.5:
  + xml-formatter: Fix allocation size of buffer
  + framepositioner: Fix runtime warning
  + Don't use volatile to mean atomic (fixes compiler warnings with
    gcc 11)
* Wed Mar 31 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.18.4:
  + group: Use proper group constructor
* Sat Jan 16 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.3:
  + launch: Ensure to add required ref to profiles from project
  + tests: fix meson test env setup to make sure we use the right
    gst-plugin-scanner
* Thu Dec 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.2:
  + Fix static build
  + ges_init(): Fix potential initialisation crash on error
- Fix the _service file and spec to really use the tarball
  generated by service.
* Thu Nov 26 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Fix minimum version of pkgconfig(gst-validate-1.0) BuildRequires.
* Wed Oct 28 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.18.1:
  + Highlighted bugfixes in 1.18.1
  - important security fixes
  - bug fixes and memory leak fixes
  - various stability and reliability improvements
  + gst-editing-services changes:
  - ges: Do not recreate auto-transitions when changing clip
    assets
  - ges: Fix a copy/paste mistake in meson file
* Mon Sep 14 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.18.0:
  + Highlights:
  - GstTranscoder: new high level API for applications to
    transcode media files from one format to another
  - High Dynamic Range (HDR) video information representation
    and signalling enhancements
  - Instant playback rate change support
  - Active Format Description (AFD) and Bar Data support
  - RTSP server and client implementations gained ONVIF trick
    modes support
  - Hardware-accelerated video decoding on Windows via
    DXVA2/Direct3D11
  - Microsoft Media Foundation plugin for video capture and
    hardware-accelerated video encoding on Windows
  - qmlgloverlay: New overlay element that renders a QtQuick
    scene over the top of an input video stream
  - imagesequencesrc: New element to easily create a video
    stream from a sequence of jpeg or png images
  - dashsink: New sink to produce DASH content
  - dvbsubenc: New DVB Subtitle encoder element
  - MPEG-TS muxing now also supports TV broadcast compliant
    muxing with constant bitrate muxing and SCTE-35 support
  - rtmp2: New RTMP client source and sink element from-scratch
    implementation
  - svthevcenc: New SVT-HEVC-based H.265 video encoder
  - vaapioverlay: New compositor element using VA-API
  - rtpmanager gained support for Google's Transport-Wide
    Congestion Control (twcc) RTP extension
  - splitmuxsink and splitmuxsrc gained support for auxiliary
    video streams
  - webrtcbin now contains some initial support for
    renegotiation involving stream addition and removal
  - RTP support was enhanced with new RTP source and sink
    elements to easily set up RTP streaming via rtp:// URIs
  - avtp: New Audio Video Transport Protocol (AVTP) plugin for
    Time-Sensitive Applications
  - Support for the Video Services Forum's Reliable Internet
    Stream Transport (RIST) TR-06-1 Simple Profile
  - Universal Windows Platform (UWP) support
  - rpicamsrc: New element for capturing from the Raspberry Pi
    camera
  - RTSP Server TCP interleaved backpressure handling
    improvements as well as support for Scale/Speed headers
  - GStreamer Editing Services gained support for nested
    timelines, per-clip speed rate control and the OpenTimelineIO
    format.
  - Autotools build system has been removed in favour of Meson
* Tue Feb 18 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Switch to meson buildsystem: Remove all conditionals.
- Replace gcc-c++ with generic c++_compiler BuildRequires.
- Add pkgconfig(gstreamer-plugins-bad-1.0) BuildRequires, meson
  checks for it.
- Add python3-gobject-devel, new dependency, needed due to changes
  elsewhere in the stack.
- Disable pkgconfig(bash-completion) BuildRequires and resulting
  file, not built when using meson buildsystem.
* Wed Dec  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.16.2:
  + Initialize debug categories before usage
* Tue Sep 24 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.16.1:
  + See main gstreamer package for changelog.
* Mon Jun 17 2019 mgorse@suse.com
- Update to version 1.16.0:
  + Highlights
  - GStreamer WebRTC stack gained support for data channels for
    peer-to-peer communication based on SCTP, BUNDLE support, as
    well as support for multiple TURN servers.
  - AV1 video codec support for Matroska and QuickTime/MP4
    containers and more configuration options and supported
    input formats for the AOMedia AV1 encoder
  - Support for Closed Captions and other Ancillary Data in video
  - Support for planar (non-interleaved) raw audio
  - GstVideoAggregator, compositor and OpenGL mixer elements are
    now in -base
  - New alternate fields interlace mode where each buffer carries
    a single field
  - WebM and Matroska ContentEncryption support in the Matroska
    demuxer
  - new WebKit WPE-based web browser source element
  - Video4Linux: HEVC encoding and decoding, JPEG encoding, and
    improved dmabuf import/export
  - Hardware-accelerated Nvidia video decoder gained support for
    VP8/VP9 decoding, whilst the encoder gained support for
    H.265/HEVC encoding.
  - Many improvements to the Intel Media SDK based
    hardware-accelerated video decoder and encoder plugin (msdk):
    dmabuf import/export for zero-copy integration with other
    components; VP9 decoding; 10-bit HEVC encoding; video
    post-processing (vpp) support including deinterlacing; and
    the video decoder now handles dynamic resolution changes.
  - The ASS/SSA subtitle overlay renderer can now handle multiple
    subtitles that overlap in time and will show them on screen
    simultaneously
  - The Meson build is now feature-complete (*) and it is now the
    recommended build system on all platforms. The Autotools
    build is scheduled to be removed in the next cycle.
  - The GStreamer Rust bindings and Rust plugins module are now
    officially part of upstream GStreamer.
  - The GStreamer Editing Services gained a gesdemux element that
    allows directly playing back serialized edit list with
    playbin or (uri)decodebin
  - Many performance improvements
- Switch to meson on Tumbleweed.
- Add libgstges.so to files.
* Fri May 31 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.14.5:
  + Fix compilation with latest GLib.
  + layer: Resort clips before syncing priorities.
  + timeline: Better handle loading inconsistent timelines.
* Wed Oct  3 2018 bjorn.lie@gmail.com
- Update to version 1.14.4:
  + Bugfix release, please see .changes in gstreamer main package.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 1.14.3:
  + Bugfix release, please see .changes in gstreamer main package.
* Tue Jul 24 2018 bjorn.lie@gmail.com
- Update to version 1.14.2:
  + python: Fix GES.Timelineset_child_property.
  + Set GLib log domain to GES.
  + group: Fix handling clips that are added to a layer.
* Sun May 20 2018 bjorn.lie@gmail.com
- Update to version 1.14.1:
  + GstPad: Fix race condition causing the same probe to be called
    multiple times
  + Fix occasional deadlocks on windows when outputting debug
    logging
  + Fix debug levels being applied in the wrong order
  + GIR annotation fixes for bindings
  + audiomixer, audioaggregator: fix some negotiation issues
  + gst-play-1.0: fix leaving stdin in non-blocking mode after exit
  + flvmux: wait for caps on all input pads before writing header
    even if source is live
  + flvmux: don't wake up the muxer unless there is data, fixes
    busy looping if there's no input data
  + flvmux: fix major leak of input buffers
  + rtspsrc, rtsp-server: revert to RTSP RFC handling of
    sendonly/recvonly attributes
  + rtpvrawpay: fix payloading with very large mtu sizes where
    everything fits into a single RTP packet
  + v4l2: Fix hard-coded enabled v4l2 probe on Linux/ARM
  + v4l2: Disable DMABuf for emulated formats when using libv4l2
  + v4l2: Always set colorimetry in S_FMT
  + asfdemux: Set stream-format field for H264 streams and handle
    H.264 in bytestream format
  + x265enc: Fix tagging of keyframes on output buffers
  + ladspa: Fix critical during plugin load on Windows
  + decklink: Fix COM initialisation on Windows
  + h264parse: fix re-use across pipeline stop/restart
  + mpegtsmux: fix force-keyframe event handling and PCR/PMT
    changes that would confuse some players with generated HLS
    streams
  + adaptivedemux: Support period change in live playlist
  + rfbsrc: Fix support for applevncserver and support NULL pool in
    decide_allocation
  + jpegparse: Fix APP1 marker segment parsing
  + h265parse: Make caps writable before modifying them, fixes
    criticals
  + fakevideosink: request an extra buffer if enable-last-sample is
    enabled
  + wasapisrc: Don't provide a clock based on WASAPI's clock
  + wasapi: Only use audioclient3 when low-latency, as it might
    otherwise glitch with slow CPUs or VMs
  + wasapi: Don't derive device period from latency time, should
    make it more robust against glitches
  + audiolatency: Fix wave detection in buffers and avoid bogus pts
    values while starting
  + msdk: fix plugin load on implementations with only HW support
  + msdk: dec: set framerate to the driver only if provided, not in
    0/1 case
  + msdk: Don't set extended coding options for JPEG encode
  + rtponviftimestamp: fix state change function init/reset causing
    races/crashes on shutdown
  + decklink: fix initialization failure in windows binary
  + ladspa: Fix critical warnings during plugin load on Windows and
    fix dependencies in meson build
  + gl: fix cross-compilation error with viv-fb
  + qmlglsink: make work with eglfs_kms
  + rtspclientsink: Don't deadlock in preroll on early close
  + rtspclientsink: Fix client ports for the RTCP backchannel
  + rtsp-server: Fix session timeout when streaming data to client
    over TCP
  + vaapiencode: h264: find best profile in those available, fixing
    negotiation errors
  + vaapi: remove custom GstGL context handling, use GstGL instead.
    Fixes GL Context sharing with WebkitGtk on wayland
  + gst-editing-services: various fixes
  + gst-python: bump pygobject req to 3.8;
    fix GstPad.set_query_function(); dist autogen.sh and
    configure.ac in tarball
  + g-i: pick up GstVideo-1.0.gir from local build directory in
    GstGL build
  + g-i: update constant values for bindings
  + avoid duplicate symbols in plugins across modules in static
    builds
  + ... and many, many more!
* Tue Apr 17 2018 bjorn.lie@gmail.com
- Update to version 1.14.0:
  + Highlights:
  - WebRTC support: real-time audio/video streaming to and from
    web browsers;
  - Experimental support for the next-gen royalty-free AV1 video
    codec
  - Video4Linux: encoding support, stable element names and
    faster device probing;
  - Support for the Secure Reliable Transport (SRT) video
    streaming protocol;
  - RTP Forward Error Correction (FEC) support (ULPFEC);
  - RTSP 2.0 support in rtspsrc and gst-rtsp-server;
  - ONVIF audio backchannel support in gst-rtsp-server and
    rtspsrc;
  - playbin3 gapless playback and pre-buffering support;
  - Tee, our stream splitter/duplication element, now does
    allocation query aggregation which is important for efficient
    data handling and zero-copy;
  - QuickTime muxer has a new prefill recording mode that allows
    file import in Adobe Premiere and FinalCut Pro while the file
    is still being written;
  - rtpjitterbuffer fast-start mode and timestamp offset
    adjustment smoothing;
  - souphttpsrc connection sharing, which allows for connection
    reuse, cookie sharing, etc;
  - nvdec: new plugin for hardware-accelerated video decoding
    using the NVIDIA NVDEC API;
  - Adaptive DASH trick play support;
  - ipcpipeline: new plugin that allows splitting a pipeline
    across multiple processes;
  - Major gobject-introspection annotation improvements for large
    parts of the library API;
  - GStreamer C# bindings have been revived and seen many updates
    and fixes;
  - The externally maintained GStreamer Rust bindings had many
    usability improvements and cover most of the API now.
    Coinciding with the 1.14 release, a new release with the 1.14
    API additions is happening.
  + Updated translations.
* Fri Mar 30 2018 bjorn.lie@gmail.com
- Update to version 1.12.5:
  + Bugs fixed: glgo#pitivi#2142, glgo#pitivi#2133, bgo#793874.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Dec 11 2017 zaitor@opensuse.org
- Update to version 1.12.4:
  + Misc fixes.
* Mon Sep 18 2017 zaitor@opensuse.org
- Update to version 1.12.3:
  + track_element: Always emit "control-binding-removed" signal.
  + Revert "timeline: Return FALSE when commiting an empty
    timeline".
  + xml-formatter: Save encoder and muxer advanced settings.
  + Enhance some pad linking issue debug logging.
  + smartmixer: Give a unique name to each compositor instances.
  + pipeline: Allow up to 2 seconds queueing in the playsink video
    queue.
  + asset:
  - Add a function to stop proxying an asset.
  - Clear loading error when reload is requested.
  + nlecomposition: Properly update segment->start/stop on commit.
  + timeline: Remove trackelements initating move from the moving
    context.
  + xml-formatter: Serialize encoding profiles in reverse order.
  + pipeline: Make sure tracks are unlinked on NULL->NULL state
    changes.
* Fri Jul 14 2017 zaitor@opensuse.org
- Update to version 1.12.2:
  + Bugs fixed: bgo#784769.
* Wed Jun 21 2017 zaitor@opensuse.org
- Update to version 1.12.1:
  + No changes, stable version bump only.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 1.12.0:
  + No changes, stable version bump.
- Changes from version 1.11.91:
  + Automatic common submodule update.
- Changes from version 1.11.90:
  + Bugs fixed: bgo#780854.
* Sat Feb 25 2017 zaitor@opensuse.org
- Update to version 1.11.2:
  + Bugs fixed: bgo#776805, bgo#778248.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.11.1:
  + Bugs fixed: bgo#774480, bgo#765967, bgo#774641, bgo#775051,
    bgo#775295, bgo#776063, bgo#776064.
- Add missing Requires on main package in devel sub package.
- Move manpages to mainpackage where the actual binary is.
- Move Changelog and README to devel package.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.10.4:
  + ges-timeline: Properly calculate absolute diff of two unsigned
    integers.
  + ges:
  - Add NULL check before dereferencing.
  - Check if GstDiscoverer could be created at init time.
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 1.10.3:
  + meson: Install ges-launch.
  + validate: Remove space breaking muting ges-launch.
* Sat Dec  3 2016 zaitor@opensuse.org
- Update to version 1.10.2:
  + Bugs fixed: bgo#774751.
* Sun Nov 27 2016 zaitor@opensuse.org
- Update to version 1.10.1:
  + Minor bugfixes.
- Changes from version 1.10.0:
  + Minor bugfixes.
* Wed Aug 24 2016 zaitor@opensuse.org
- Update to version 1.8.3 (boo#996937):
  + Revert 3 commits:
  - "video-source: Expose deinterlace-[fields, mode, tff] child
    properties".
  - "container: Handle setting children properties that need
    prefixing".
  - "formatter: Prefix all children properties in the XML
    formatter".
* Fri Jul  1 2016 toddrme2178@gmail.com
- Fix Group tag.
* Wed Jun 15 2016 zaitor@opensuse.org
- Update to version 1.8.2:
  + bgo765853: timeline: rename "track-element" to
    "track_element" in select-tracks-for-object documentation.
  + bgo#765856: g-i: use only " ges/ges.h " as c-include for
    introspection.
  + bgo#766455: nlecomposition: ensure elements pending to be added
    are not leaked.
  + bgo#766459: ges: ges_asset_set_proxy documentation fix and add
    some g-i annotations.
  + bgo#766524: audio-source: unref private capsfilter reference on
    finalize.
  + bgo#767053: nlecomposition: Fix race condition in seek handling
    causing deadlocks.
  + bgo#767293: ges-uri-asset: GstDiscoverer can return a valid
    info but a non-OK result, consider this an error.
* Thu Apr 21 2016 zaitor@opensuse.org
- Update to version 1.8.1:
  + titlesource: Add support for absolute positionning.
* Sat Mar 26 2016 zaitor@opensuse.org
- Update to version 1.8.0:
  + Hardware-accelerated zero-copy video decoding on Android
  + New video capture source for Android using the
    android.hardware.Camera API.
  + Windows Media reverse playback support (ASF/WMV/WMA).
  + New tracing system provides support for more sophisticated
    debugging tools.
  + New high-level GstPlayer playback convenience API.
  + Initial support for the new Vulkan API, see Matthew Waters'
    blog post for more details.
  + Improved Opus audio codec support: Support for more than two
    channels; MPEG-TS demuxer/muxer can now handle Opus;
    sample-accurate encoding/decoding/transmuxing with Ogg,
    Matroska, ISOBMFF (Quicktime/MP4), and MPEG-TS as container;
    new codec utility functions for Opus header and caps handling
    in pbutils library. The Opus encoder/decoder elements were
    also moved to gst-plugins-base (from -bad), and the opus RTP
    depayloader/payloader to -good.
  + GStreamer VAAPI module now released and maintained as part of
    the GStreamer project.
  + Asset proxy support in the GStreamer Editing Services.
- Replace gobject-introspection-devel for
  pkgconfig(gobject-introspection-1.0) BuildRequires.
- Add explicit pkgconfig(glib-2.0) BuildRequires and version it.
- Add pkgconfig(gst-validate-1.0) BuildRequires: New dependency.
* Mon Jan 18 2016 zaitor@opensuse.org
- Update to version 1.6.2:
  + bash-completion: Disable during "make distcheck".
  + Revert "build: fix make distcheck."
  + tests: Properly setup GST_PLUGIN_PATH in test environement.
  + Dist gst-editing-services.doap.
  + ges: Set restriction caps in the audio source caps filter.
  + formatter: Do not serialize top effect priorities.
  + launcher: Make sure to not activate validate twice when simply
    loading a scene.
* Wed Jan 13 2016 antoine.belvire@laposte.net
- Move the NLE GStreamer plugin (libgstnle.so) from devel package
  to libges
* Sun Nov  1 2015 zaitor@opensuse.org
- Update to version 1.6.1:
  + TRY_GET leaks string pointer.
  + structure-parser: leaks internal lists.
  + nleoperation: leaks srcpad.
  + ges-project: leaks internal file info.
* Fri Oct  2 2015 zaitor@opensuse.org
- Update to version 1.6.0:
  + For changelog, see mainpackage changes, everything is condenced
    there.
  + nlecomposition allocates unused UpdateCompositionData.
- Add flex and pkgconfig(bash-completion) BuildRequires: New
  dependencies.
* Tue Nov  4 2014 dimstar@opensuse.org
- Update to 1.4.0:
  + Add support to gst-validate, allowing us to easily write
    integration testsuites.
  + Add multifilesrc support.
  + Give a name/unique identifier to all GESTimelineElement in the
    timeline.
  + ges-launch: Cleanup and allow using encoding profiles from
    project files.
  + bgo#738624: gst-editing-services fails to build with current
    git gstreamer-validate via Cerbero.
* Fri Jul 25 2014 dimstar@opensuse.org
- Upate to version 1.2.1:
  + ges-launch:
  - Properly handle project loading.
  - Format the position printing as in gst-validate and friends.
  - Not being able to load an asset is an error.
  + pipeline: Do not set EncodingProfile.presence when we have no
    track for the type.
  + Build fixes.
* Sat Apr 12 2014 zaitor@opensuse.org
- Update to version 1.2.0:
  + Bugs fixed: bgo#673040, bgo#651806, bgo#432662, bgo#644943,
    bgo#645385, bgo#646293, bgo#669827, bgo#669959, bgo#672751,
    bgo#673038, bgo#673714, bgo#677048, bgo#679941, bgo#681774,
    bgo#692864, bgo#695267, bgo#696226, bgo#701115, bgo#702424,
    bgo#702426, bgo#702605, bgo#703152, bgo#706855, bgo#707914,
    bgo#709777, bgo#710168, bgo#710172, bgo#710390, bgo#721111,
    bgo#724337, bgo#726365, bgo#678558, bgo#663869.
- Drop ges-extra-semicolon.patch: Fixed upstream.
* Sat Mar 15 2014 schwab@suse.de
- ges-extra-semicolon.patch: remove extra semicolon
* Tue Jan 21 2014 dimstar@opensuse.org
- Update License Tag: the source tarball contains GPL-3.0+ code
  for the samples. The library is licensed LGPL-2.1+.
* Sat Nov 30 2013 dimstar@opensuse.org
- Initial package, version 1.1.90.
